/**
 * Declares the interface of the Cowl axiom provider.
 *
 * @author Ivano Bilenchi
 *
 * @file
 */

#ifndef TME_COWL_AXIOM_PROVIDER_H
#define TME_COWL_AXIOM_PROVIDER_H

#include "cowl_std.h"
#include "tme_std.h"

TME_BEGIN_DECLS

/// @cond
cowl_struct_decl(CowlOntology);
tme_struct_decl(TmeAxiomProvider);
/// @endcond

/**
 * Allocates a new axiom provider backed by a Cowl ontology.
 *
 * @param ontology Ontology instance.
 * @return Axiom provider instance.
 */
TmeAxiomProvider* tme_cowl_axiom_provider_alloc(CowlOntology *ontology);

/**
 * Deallocates the axiom provider.
 *
 * @param provider Axiom provider instance.
 */
void tme_cowl_axiom_provider_free(TmeAxiomProvider *provider);

TME_END_DECLS

#endif // TME_COWL_AXIOM_PROVIDER_H
