/**
 * Declares APIs for converting between Cowl and Tiny-ME entities.
 *
 * @author Ivano Bilenchi
 *
 * @file
 */

#ifndef TME_COWL_ENTITY_H
#define TME_COWL_ENTITY_H

#include "cowl_entity.h"
#include "tme_atomic.h"
#include "tme_std.h"

TME_BEGIN_DECLS

/**
 * Converts a CowlClass into a TmeAtomicConcept.
 *
 * @param CLS [CowlClass*] Class instance.
 * @return [TmeAtomicConcept] Entity pointer.
 */
#define tme_cowl_class_to_atomic(CLS) ((TmeAtomicConcept)(CLS))

/**
 * Converts a CowlObjProp into a TmeAtomicRole.
 *
 * @param PROP [CowlObjProp*] Object property instance.
 * @return [TmeAtomicRole] Entity pointer.
 */
#define tme_cowl_obj_prop_to_atomic(PROP) ((TmeAtomicRole)(PROP))

/**
 * Converts a CowlNamedInd into a TmeAtomicIndividual.
 *
 * @param IND [CowlNamedInd*] Named individual instance.
 * @return [TmeAtomicIndividual] Entity pointer.
 */
#define tme_cowl_named_ind_to_atomic(IND) ((TmeAtomicIndividual)(IND))

/**
 * Converts a TmeAtomicConcept into a CowlClass.
 *
 * @param CONCEPT [TmeAtomicConcept] Concept.
 * @return [CowlClass] Class instance.
 */
#define tme_cowl_class_from_atomic(CONCEPT) ((CowlClass *)(CONCEPT))

/**
 * Converts a TmeAtomicRole into a CowlObjProp.
 *
 * @param ROLE [TmeAtomicRole] Role.
 * @return [CowlObjProp] Object property instance.
 */
#define tme_cowl_obj_prop_from_atomic(ROLE) ((CowlObjProp *)(ROLE))

/**
 * Converts a TmeAtomicIndividual into a CowlNamedInd.
 *
 * @param IND [TmeAtomicIndividual] Individual.
 * @return [CowlNamedInd] Named individual instance.
 */
#define tme_cowl_named_ind_from_atomic(IND) ((CowlNamedInd *)(IND))

/**
 * Converts a CowlEntity into a CowlEntityPtr.
 *
 * @param entity Entity instance.
 * @return Entity pointer.
 */
TmeEntityPtr tme_cowl_entity_to_atomic(CowlEntity entity);

TME_END_DECLS

#endif // TME_COWL_ENTITY_H
