/**
 * Defines the vocabulary data structure.
 *
 * @author Ivano Bilenchi
 *
 * @file
 */

#ifndef TME_VOCABULARY_H
#define TME_VOCABULARY_H

#include "tme_atomic.h"

TME_BEGIN_DECLS

/**
 * Vocabulary containing reserved entity identifiers.
 *
 * It is necessary for the reasoner to know in advance which entity identifiers belong to
 * special entities, such as the top and bottom concepts. This information is specified
 * via a TmeVocabulary instance.
 */
typedef tme_struct(TmeVocabulary) {

    /// Entity identifier of the top concept.
    TmeAtomicConcept const top_concept;

    /// Entity identifier of the bottom concept.
    TmeAtomicConcept const bottom_concept;

} TmeVocabulary;

TME_END_DECLS

#endif // TME_VOCABULARY_H
